Learn R Programming

PkgsFromFiles (version 0.5)

pff_find_pkgs_from_file: Finds used packages from a single file

Description

This function will search the names of R packages used in the script

Usage

pff_find_pkgs_from_file(f.in)

Arguments

f.in

File to search for pattern

Value

A character object with all packages, separated by ' ; '

Examples

Run this code
# NOT RUN {
# }
# NOT RUN {
my.f <- system.file('extdata/Example_Script_1.R', package = 'PkgsFromFiles')
pkg.out <- pff_find_pkgs_from_file(my.f)
# }
# NOT RUN {
# }

Run the code above in your browser using DataLab