powered by
This function will search the names of R packages used in the script
pff_find_pkgs_from_file(f.in)
File to search for pattern
A character object with all packages, separated by ' ; '
# NOT RUN { # } # NOT RUN { my.f <- system.file('extdata/Example_Script_1.R', package = 'PkgsFromFiles') pkg.out <- pff_find_pkgs_from_file(my.f) # } # NOT RUN { # }
Run the code above in your browser using DataLab